---
name: Bug report
about: Create a bug report to help us improve
title: ''
labels: bug
assignees: ''

---

### Describe the bug

A clear and concise description of what the bug is.

Project version that this has been tested on: [e.g. 1.0.0]

### To Reproduce

Steps to reproduce the behavior:
1. Run command '...'
2. Click on '...'
3. Type in '...'
4. See error

### Expected behavior

A clear and concise description of what you expected to happen.

### Screenshots

If applicable, add screenshots to help explain your problem.
